diff --git a/typo3/sysext/backend/Classes/Http/RequestHandler.php b/typo3/sysext/backend/Classes/Http/RequestHandler.php
index 3441d5f152f22ca305cfac4110c8239b3423dd5c..2508f5cebfe9abd856577668a57b84d282eeb23f 100644
--- a/typo3/sysext/backend/Classes/Http/RequestHandler.php
+++ b/typo3/sysext/backend/Classes/Http/RequestHandler.php
@@ -17,7 +17,6 @@ namespace TYPO3\CMS\Backend\Http;
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Routing\Exception\InvalidRequestTokenException;
-use TYPO3\CMS\Backend\Routing\Exception\RouteNotFoundException;
 use TYPO3\CMS\Core\Core\Bootstrap;
 use TYPO3\CMS\Core\Http\RequestHandlerInterface;
 use TYPO3\CMS\Core\Http\Response;
@@ -129,7 +128,7 @@ class RequestHandler implements RequestHandlerInterface
      *
      * @param ServerRequestInterface $request
      * @return ResponseInterface
-     * @throws RouteNotFoundException when no route is registered
+     * @throws InvalidRequestTokenException if the request could not be verified
      * @throws \InvalidArgumentException when a route is found but the target of the route cannot be called
      */
     protected function dispatch($request)
diff --git a/typo3/sysext/backend/Classes/Http/RouteDispatcher.php b/typo3/sysext/backend/Classes/Http/RouteDispatcher.php
index 19db8cb04a1e84c319c7c5c3a725f2674b1cde3c..66a32b8a11b1adf33b987f68117c273b1aed5fa2 100644
--- a/typo3/sysext/backend/Classes/Http/RouteDispatcher.php
+++ b/typo3/sysext/backend/Classes/Http/RouteDispatcher.php
@@ -35,7 +35,7 @@ class RouteDispatcher extends Dispatcher implements DispatcherInterface
      * @param ServerRequestInterface $request the current server request
      * @param ResponseInterface $response the prepared response
      * @return ResponseInterface the filled response by the callable / controller/action
-     * @throws RouteNotFoundException if the route was not found
+     * @throws InvalidRequestTokenException if the route was not found
      * @throws \InvalidArgumentException if the defined target for the route is invalid
      */
     public function dispatch(ServerRequestInterface $request, ResponseInterface $response)
diff --git a/typo3/sysext/backend/Classes/Http/AjaxRequestHandler.php b/typo3/sysext/backend/Classes/Http/AjaxRequestHandler.php
index f1019a0c635d7a7f589e822c830e08671a03ae85..c92491ea4a81a7664e58b92d0bdd74195bd93885 100644
--- a/typo3/sysext/backend/Classes/Http/AjaxRequestHandler.php
+++ b/typo3/sysext/backend/Classes/Http/AjaxRequestHandler.php
@@ -16,9 +16,8 @@ namespace TYPO3\CMS\Backend\Http;
 
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
+use TYPO3\CMS\Backend\Routing\Exception\InvalidRequestTokenException;
 use TYPO3\CMS\Backend\Routing\Exception\ResourceNotFoundException;
-use TYPO3\CMS\Backend\Routing\Exception\RouteNotFoundException;
-use TYPO3\CMS\Backend\Routing\Route;
 use TYPO3\CMS\Core\Core\Bootstrap;
 use TYPO3\CMS\Core\FormProtection\FormProtectionFactory;
 use TYPO3\CMS\Core\Http\RequestHandlerInterface;
@@ -151,7 +150,7 @@ class AjaxRequestHandler implements RequestHandlerInterface
      * @param ServerRequestInterface $request
      * @return ResponseInterface $response
      * @throws ResourceNotFoundException if no valid route was found
      * @throws RouteNotFoundException if the request could not be verified
      */
     protected function dispatch(ServerRequestInterface $request)
     {
@@ -151,7 +150,7 @@ class AjaxRequestHandler implements RequestHandlerInterface
      * @return ResponseInterface $response
      * @throws ResourceNotFoundException if no valid route was found
-     * @throws RouteNotFoundException if the request could not be verified
+     * @throws InvalidRequestTokenException if the request could not be verified
      */
     protected function dispatch(ServerRequestInterface $request)